'use strict'

const querystring = require('querystring')

module.exports = (request) => {
  return new Promise((resolve, reject) => {
    let parse = {}

    if (request.headers['content-type'] === 'application/json') {
      parse = JSON.parse
    } else if (
      request.headers['content-type'] === 'application/x-www-form-urlencoded'
    ) {
      parse = querystring.parse
    } else {
      return reject(new Error('Unsupported content type'))
    }

    let body = ''

    request.setEncoding('utf8')

    request.on('data', chunk => {
      body += chunk
    })

    request.on('end', () => {
      try {
        const data = parse(body)

        return resolve(data)
      } catch (error) {
        return reject(new Error(error))
      }
    })
  })
}
